@@ -101,4 +101,10 @@ class StringSort:
                     | (list1[i] == str(sign5)) | (list1[i] == str(sign6)) | (list1[i] == str(sign7)) | \
                     (list1[i] == str(sign8)) | (list1[i] == str(sign9)) | (list1[i] == str(sign10)):
                 list1[i] = ''
+        return ''.join(list1)
+
+    def alphabetical_order(self):
+        list1 = []
+        list1.extend(self.string)
+        list1.sort()
         return ''.join(list1)
\ No newline at end of file
